Django Custom Startapp

A Django management command to create applications with a custom structure:





Includes urls.py



Creates views/ and models/ directories instead of views.py and models.py

Installation

pip install django-custom-startapp

Usage

python manage.py customstartapp myapp

This will create an app with the following structure:

myapp/
├── __init__.py
├── admin.py
├── apps.py
├── migrations/
│   └── __init__.py
├── models/
│   └── __init__.py
├── tests.py
├── urls.py
└── views/
    └── __init__.py

Requirements





Django >= 3.0



Python >= 3.6